Quickstart — mosaik 2.0a2 documentation

# Quickstart

This guide assumes that you are somewhat proficient with Python and know what pip and virtualenv. Else, you should follow the detailed instructions.

Mosaik runs on Linux, OS X and Windows. It requires Python 3.3 or newer. To install everything, you need the package manager Pip which is bundled with Python 3.4 and above.

We also strongly recommend you to install everything into a virtualenv.

You can then install mosaik with pip:

    $ pip install mosaik

There is also a demo scenario that you can try. You can get it from Bitbucket. If you have binary packages for numpy and scipy available, you may install them first (they are required for the load flow analysis with PYPOWER):

    $ hg clone https://bitbucket.org/mosaik/mosaik-demo
    $ cd mosaik-demo/
    $ pip install -r requirements.txt
    $ python demo.py

Then open your browser and go to http://localhost:8000.